@@ -1,7 +1,7 @@
 /*
  *  Entangle: Tethered Camera Control & Capture
  *
- *  Copyright (C) 2009-2012 Daniel P. Berrange
+ *  Copyright (C) 2009-2015 Daniel P. Berrange
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -264,9 +264,9 @@ static gint entangle_session_next_digit(EntangleSession *session)
     const gchar *template = strchr(priv->filenamePattern, 'X');
     gchar *prefix = g_strndup(priv->filenamePattern, (template - priv->filenamePattern));
     gint prefixlen = strlen(prefix);
-    gint templatelen = 0;
+    gsize templatelen = 0;
     const gchar *postfix;
-    gint postfixlen;
+    gsize postfixlen;
 
     while (*template == 'X') {
         templatelen++;
@@ -276,13 +276,13 @@ static gint entangle_session_next_digit(EntangleSession *session)
     postfix = template;
     postfixlen = strlen(postfix);
 
-    ENTANGLE_DEBUG("Template '%s' with prefixlen %d, %d digits and postfix %d",
+    ENTANGLE_DEBUG("Template '%s' with prefixlen %d, %zu digits and postfix %zu",
                    priv->filenamePattern, prefixlen, templatelen, postfixlen);
 
     while (images) {
         EntangleImage *image = images->data;
         const gchar *name = entangle_image_get_filename(image);
-        gsize remain = templatelen;
+        gsize used = 0;
         gint digit = 0;
 
         if (!g_str_has_prefix(name, priv->directory)) {
@@ -304,15 +304,15 @@ static gint entangle_session_next_digit(EntangleSession *session)
         name += prefixlen;
 
         /* Skip over filename matching digits */
-        while (remain && g_ascii_isdigit(*name)) {
+        while (used < templatelen && g_ascii_isdigit(*name)) {
             digit *= 10;
             digit += *name - '0';
             name++;
-            remain--;
+            used++;
         }
 
         /* See if unexpectedly got a non-digit before end of template */
-        if (remain) {
+        if (used < templatelen) {
             ENTANGLE_DEBUG("File %s has too few digits",
                            entangle_image_get_filename(image));
             goto next;
@@ -415,24 +415,26 @@ char *entangle_session_next_filename(EntangleSession *session,
     EntangleSessionPrivate *priv = session->priv;
     const char *srcname = entangle_camera_file_get_name(file);
     char *dstname = NULL;
-    const char *offset = strrchr(srcname, '.');
-    char *ext;
-    char *srcprefix;
+    char *ext = NULL;
+    char *srcprefix = NULL;
 
     ENTANGLE_DEBUG("Next filename %s against (%s, %s)",
                    srcname,
                    priv->lastFilePrefixSrc ? priv->lastFilePrefixSrc : "",
                    priv->lastFilePrefixDst ? priv->lastFilePrefixDst : "");
 
-    if (!offset) {
-        srcprefix = g_strdup(srcname);
-        ext = g_strdup("jpeg");
-    } else {
-        srcprefix = g_strndup(srcname, (offset - srcname));
-        ext = g_ascii_strdown(offset + 1, -1);
+    if (srcname) {
+        const char *offset = strrchr(srcname, '.');
+        if (!offset) {
+            srcprefix = g_strdup(srcname);
+        } else {
+            srcprefix = g_strndup(srcname, (offset - srcname));
+            ext = g_ascii_strdown(offset + 1, -1);
+        }
     }
 
-    if (priv->lastFilePrefixSrc &&
+    if (srcprefix &&
+        priv->lastFilePrefixSrc &&
         priv->lastFilePrefixDst &&
         g_str_equal(priv->lastFilePrefixSrc, srcprefix)) {
     } else {
@@ -446,7 +448,7 @@ char *entangle_session_next_filename(EntangleSession *session,
         dstname = g_strdup_printf("%s/%s.%s",
                                   priv->directory,
                                   priv->lastFilePrefixDst,
-                                  ext);
+                                  ext ? ext : "jpeg");
     g_free(ext);
 
     ENTANGLE_DEBUG("Built '%s'", dstname);
